@@ -1,8 +1,6 @@
 pub mod parser;
 pub mod translator;
 
-use wasm_bindgen::prelude::*;
-
 pub type MarkdownText = Vec<MarkdownInline>;
 
 #[derive(Clone, Debug, PartialEq)]
@@ -24,7 +22,6 @@ pub enum MarkdownInline {
     Plaintext(String),
 }
 
-#[wasm_bindgen]
 pub fn markdown(md: &str) -> String {
     match parser::parse_markdown(md) {
         Ok((_, m)) => translator::translate(m),
